<?php

namespace Modules\CMP\Controllers;

class AF {
    protected $connection;
    protected $environment;
    protected $Utils;
    public function __construct($connection, $environment, $UtilsIntegracao){
        $this->connection = $connection;
        $this->environment = $environment;
        $this->Utils = $UtilsIntegracao;
    }
    
    //Consulta e retorna as AFs segundo filtros informados
    private function consultaAFs($cdfilial, $dtinicial, $dtfinal, $idbaixaaf, $nrautoforn, $nrinsjurforn){
        $query = "SELECT AUTOFORNE.CDFILDEST, AUTOFORNE.CDFILLANC, AUTOFORNE.NRAUTOFORN, AUTOFORNE.CDFILDEST CDFILIAL, 
                         AUTOFORNE.DTAUTOFORN, CASE 
                                                  WHEN NVL(AUTOFORNE.IDAFEXPIRADA, 'N') = 'S'
                                                  THEN '8'
                                                  ELSE NVL(AUTOFORNE.IDBAIXAAF, '0') 
                                               END IDBAIXAAF, AUTOFORNE.VRTOTALAF,
                         FILIAL.NMFILIAL, FORNECEDOR.NRINSJURFORN, FORNECEDOR.NMRAZSOCFORN, OPERADOR.NMOPERADOR,
                         EMPRESA.NRINSJUREMPR,
                         SUM(ITEMAUTF.QTPROGENTAF*ITEMAUTF.VRPREUNIAF) VRTOTALAFBR,
                         NVL(AUTOFORNE.IDAUTOFORNEX, 'N') IDAUTOFORNEX,
                         MAX((SELECT LISTAGG(DSJUSTSOLEXT,' | ') WITHIN GROUP (ORDER BY DSJUSTSOLEXT)
                                FROM ( SELECT DISTINCT DSJUSTSOLEXT  
                                         FROM MOVSOLEXT, ITEMSOLI, PRODUTO P
                                        WHERE CDFILSOLEXT =  ITEMSOLI.CDFILSOLI
                                          AND CDFILLANCEXT = ITEMSOLI.CDFILLAN
                                          AND NRSOLIMOVEXT = ITEMSOLI.NRSOLICMP
                                          AND ITEMSOLI.CDPRODUTO = P.CDPRODUTO
                                          AND ITEMSOLI.DTPROGENTR = ITEMAUTF.DTENTRITMSOL
                                          AND P.CDPRODESTO        = PRODUTO.CDPRODESTO
                                          AND ITEMSOLI.CDFILSOLI  = ITEMAUTF.CDFILDEST))) DSJUSTSOLEXT
                    FROM AUTOFORNE INNER JOIN FORNECEDOR ON AUTOFORNE.CDFORNECED = FORNECEDOR.CDFORNECED
                                   INNER JOIN FILIAL ON AUTOFORNE.CDFILDEST = FILIAL.CDFILIAL
                                   INNER JOIN OPERADOR ON AUTOFORNE.CDOPERADOR = OPERADOR.CDOPERADOR
                                   INNER JOIN ITEMAUTF ON ITEMAUTF.CDFILDEST = AUTOFORNE.CDFILDEST
                                                      AND ITEMAUTF.CDFILLANC = AUTOFORNE.CDFILLANC
                                                      AND ITEMAUTF.NRAUTOFORN = AUTOFORNE.NRAUTOFORN
                                   INNER JOIN EMPRESA ON EMPRESA.CDEMPRESA = FILIAL.CDEMPRESA
                                   INNER JOIN PRODUTO ON PRODUTO.CDPRODUTO = ITEMAUTF.CDPRODUTO
                   WHERE AUTOFORNE.CDFILDEST = :CDFILDEST
                     AND (INSTR(','||:IDBAIXAAF||',', NVL(AUTOFORNE.IDBAIXAAF, '0')) > 0)
                     AND ((:NRAUTOFORN IS NULL) OR (AUTOFORNE.NRAUTOFORN = :NRAUTOFORN))
                     AND ((:NRINSJURFORN IS NULL) OR (FORNECEDOR.NRINSJURFORN = :NRINSJURFORN))
                     AND ITEMAUTF.DTPROGENTAF BETWEEN :DTINICIAL AND :DTFINAL
                   GROUP BY AUTOFORNE.CDFILDEST, AUTOFORNE.CDFILLANC, AUTOFORNE.NRAUTOFORN, AUTOFORNE.CDFILDEST, 
                            AUTOFORNE.DTAUTOFORN, CASE 
                                                     WHEN NVL(AUTOFORNE.IDAFEXPIRADA, 'N') = 'S'
                                                     THEN '8'
                                                     ELSE NVL(AUTOFORNE.IDBAIXAAF, '0') 
                                                  END, AUTOFORNE.VRTOTALAF,
                            FILIAL.NMFILIAL, FORNECEDOR.NRINSJURFORN, FORNECEDOR.NMRAZSOCFORN, OPERADOR.NMOPERADOR, EMPRESA.NRINSJUREMPR,
                            NVL(AUTOFORNE.IDAUTOFORNEX, 'N')";
        $params = [
            "CDFILDEST"    => $cdfilial,
            "NRAUTOFORN"   => $nrautoforn,
            "NRINSJURFORN" => $nrinsjurforn,
            "IDBAIXAAF"    => $idbaixaaf,
            "DTINICIAL"    => $dtinicial,
            "DTFINAL"      => $dtfinal
        ];
        $prepared = $this->connection->prepare($query);
        $prepared->execute($params);
        return $prepared->fetchAll();
    }
    
    //Monta destrição para o status BAIXAAF
    private function montaDsBaixaAF($idbaixaaf){
        switch($idbaixaaf):
            case "0":
                return "Em aberto";
                break;
            case "1":
                return "Baixa parcial";
                break;
            case "2":
                return "Baixa total";
                break;
            case "3":
                return "Baixa manual";
                break;
            case "4":
                return "Encerrada";
                break;
            case "5":
                return "Cancelada";
                break;
            case "6":
                return "Bloqueada";
                break;
            case "7":
                return "Aguardando envio via EDI";
                break;
            case "8":
                return "Expirada";
                break;
            default:
                return "";
        endswitch;
    }
    
    //Monta destrição para o status de AF Extra
    private function montaDsAFExtra($idafextra){
        switch($idafextra):
            case "N":
                return "Não";
                break;
            case "S":
                return "Sim";
                break;
            case "":
                return "";
                break;
            default:
                return "";
        endswitch;
    }
    
    private function getMaxProductLevel()
    {
        try {
            $query = "SELECT MAX(CDNVPRODUTO) CDNVPRODUTO
                        FROM PRODUTO";
            $prepared = $this->connection->prepare($query);
            $prepared->execute();
            $maxLevel = $prepared->fetch();
            return $maxLevel['CDNVPRODUTO'] >= '3' ? '3' : $maxLevel['CDNVPRODUTO'];
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
    //Consulta e retorna os produtos da AF indicada
    private function consultaProdutosAF($cdfildest, $cdfillanc, $nrautoforn, $dtinicial, $dtfinal){
        $productLevel = $this->getMaxProductLevel();
        $query = "SELECT PRODUTO.CDARVPROD, PRODUTO.NMPRODUTO, PRODUTONVL.CDARVPROD CDNVARVPROD, PRODUTONVL.NMPRODUTO NMNVPRODUTO, 
                         PRODUTO.CDBARPRODUTO, PRODUTO.SGUNIDADE, UNIDMEDIDA.DSUNIDADE, TO_CHAR(ITEMAUTF.DTPROGENTAF, 'YYYYMMDD') DTPROGENTAF, 
                         ITEMAUTF.QTPROGENTAF, ITEMAUTF.QTEFETENTRAF, ITEMAUTF.VRPREUNIAF, NVL(ITEMAUTF.IDBAIXITMAF, 0) IDBAIXITMAF,
                         MARCA.CDMARCA, MARCA.NMMARCA
                    FROM ITEMAUTF
                         INNER JOIN PRODUTO ON ITEMAUTF.CDPRODUTO = PRODUTO.CDPRODUTO
                         INNER JOIN MARCA ON ITEMAUTF.CDMARCA = MARCA.CDMARCA
                         INNER JOIN UNIDMEDIDA ON PRODUTO.SGUNIDADE = UNIDMEDIDA.SGUNIDADE
                         INNER JOIN PRODUTO PRODUTONVL ON PRODUTO.CDARVPROD LIKE PRODUTONVL.CDARVPROD||'%'
                   WHERE ITEMAUTF.CDFILDEST     = :CDFILDEST
                     AND ITEMAUTF.CDFILLANC     = :CDFILLANC
                     AND ITEMAUTF.NRAUTOFORN    = :NRAUTOFORN
                     AND ITEMAUTF.DTPROGENTAF BETWEEN :DTINICIAL AND :DTFINAL
                     AND PRODUTONVL.CDNVPRODUTO = :CDNVPRODUTO";
        $params = [
            "CDFILDEST"   => $cdfildest,
            "CDFILLANC"   => $cdfillanc,
            "NRAUTOFORN"  => $nrautoforn,
            "DTINICIAL"   => $dtinicial,
            "DTFINAL"     => $dtfinal,
            "CDNVPRODUTO" => $productLevel
        ];
        $prepared = $this->connection->prepare($query);
        $prepared->execute($params);
        return $prepared->fetchAll();
    }
    
    
    /***
     * Endpoint: cmp/af
     * Retorna lista de AFs e seus produtos
     * Parâmetros obrigatórios
     *      CDFILIAL, DTINICIAL, DTINFINAL, IDBAIXAAF
     * Parâmetros opcionais
     * NRAUTOFORN, NRINSJURFORN
     * Retorno: array de serviços
     * ***/
    public function endpointGetAF($request, $response){
        try{
            $cdfilial = $this->Utils->parametro($request, 'CDFILIAL');
            $dtinicial = $this->Utils->parametro($request, 'DTINICIAL');
            if(!$this->Utils->dataValida($dtinicial)){
                $this->Utils->incluiMensagem("Data incial ( $dtinicial ) não é um valor válido", true);
            }
            $dtfinal = $this->Utils->parametro($request, 'DTFINAL');
            if(!$this->Utils->dataValida($dtfinal)){
                $this->Utils->incluiMensagem("Data final ( $dtfinal ) não é um valor válido", true);
            }
            $idbaixaaf = $this->Utils->parametro($request, 'IDBAIXAAF');
            $nrautoforn = $this->Utils->parametro($request, 'NRAUTOFORN');
            $nrinsjurforn = $this->Utils->parametro($request, 'NRINSJURFORN');
            
            if($this->Utils->statusAtual() == 'E'){
                $this->Utils->retornoJSONStatusMensagem($response);
                return;    
            }
            $AFs = $this->consultaAFs($cdfilial, $dtinicial, $dtfinal, $idbaixaaf, $nrautoforn, $nrinsjurforn);
            foreach($AFs as &$af){
                $af['DSBAIXAAF'] = $this->montaDsBaixaAF($af['IDBAIXAAF']);
                if ($af['IDAUTOFORNEX'] == 'S'){
                    $af['DSJUSTSOLEXT'] = substr($af['DSJUSTSOLEXT'], 0, 100);    
                } else{
                    $af['DSJUSTSOLEXT'] = '';                
                }
                $af['IDAUTOFORNEX'] = $this->montaDsAFExtra($af['IDAUTOFORNEX']);
                $Produtos = $this->consultaProdutosAF($af['CDFILDEST'], $af['CDFILLANC'], $af['NRAUTOFORN'], $dtinicial, $dtfinal);
                $Produtos_Arry = array();
                foreach($Produtos as &$produtos){
                    $produtos['IDBAIXITMAF'] = $this->montaDsBaixaAF($produtos['IDBAIXITMAF']);  
                    array_push($Produtos_Arry, $produtos);
                }    
                $af['produtos'] = $Produtos_Arry;
            }
            $this->Utils->retornoJSON($response, $AFs);
        }catch(\Exception $e){
            if($this->Utils->modoDesenvolvedor())
                throw $e;
            $this->Utils->incluiMensagem("Ocorreu um erro não esperado na execução da rotina. Verifique os parâmetros e tente novamente", true);
            $this->Utils->retornoJSONStatusMensagem($response);
        }
    }
    
}