<?php

/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */

namespace Geral\Logic\PropostaComercial;

/**
 * Description of CopiaProspectToCliente
 *
 * @author phillipesilva
 */

use Indeterminado\Entities\Cursoprospect;
use Indeterminado\Entities\Qualifprosp;
use Qualificacao\Entities\Histqualpros;
use Qualificacao\Entities\Movocorr;
use Faturamento\Entities\Observclie;
use Faturamento\Entities\Parcliefas;
use SistemaQualidade\Entities\Acao;
use Academico\Entities\Endeprospect;
use Academico\Entities\Estinteresse;
use Academico\Entities\Observprosp;
use Academico\Entities\Prospfilial;
use Academico\Entities\Escopros;
use Producao\Entities\Auditoria;
use Relatione\Entities\Evolcont;
use Teknisa\Entities\Maladireta;
use Setforms2\Shared\Registry;
use Geral\Entities\Propostafas;
use Geral\Entities\Parcnegocio;
use Geral\Entities\Inteprosp;
use Geral\Entities\Inteclie;
use Geral\Entities\Prospect;
use Geral\Entities\Parceria;
use Geral\Entities\Endeclie;
use Geral\Entities\Cliente;
use Geral\Entities\Contato;
use Geral\Entities\Tarefa;
use Geral\Util\NovoCodigo;
use Geral\Util\DateUtil;
use Geral\Util\Ambiente;

//Classe com o mesmo funcionamento da procedure COPIA_PROSPECT_CLIENTE
class CopiaProspectToCliente
{
    const CUSTOMIZACAO = '1';
    const LICENCAUSO   = '2';
    const MENSALIDADE  = '3';
    const MAODEOBRA    = '5';
    const SUPORTE      = '6';
    
    public static function copiaDadosToCliente($dadosAceite) 
    {
        $entityManager = Registry::getEntityManager();        
          
        //Verifica e desabilita as triggers para realizar as inclusões.   
        $arrayTriggers = self::disableTriggers();

        try {
            $cliente = Cliente::findOneByCdclienteAndNrorg($dadosAceite['CDCLIENTE'], $dadosAceite['NRORG']);
            
            if(is_object($cliente)) {
                tk_abort('Cliente já cadastrado.');
            } else {                
                //Pega os dados do Prospect
                $dadosProsp = Prospect::getRepository()->consultaDadosProspect($dadosAceite['CDPROSPECT']);
                
                //Insere os dados no Cliente
                self::insertCliente($dadosAceite, $dadosProsp[0]);

                $parceria = Parceria::getRepository()->consultaParceriaAceitePco($dadosProsp[0]['NRPARCNEGOCIO']);
                
                //Verifica se existe parcerias, se não insere a mesma.
                if($parceria[0]['PARCERIAS'] == 0) {
                    //Novo Codigo sem commit
                    $nrParceria = NovoCodigo::geraCodigo($dadosAceite['NRORG'], 'PARCERIA', 1, 10, false, false);
                    self::insertParceria($nrParceria, $dadosProsp[0]['NRPARCNEGOCIO'], $dadosAceite['NRORG']);
                }

                self::atualizaParcNegocio($dadosProsp[0]['NRPARCNEGOCIO'], $dadosAceite['NRORG']);
                
                //Busca todos endereços do prospect e insere no cliente
                $enderecos = Endeprospect::getRepository()->consultaEndeProspAceitePco($dadosAceite['CDPROSPECT']);

                $auxEnde = false;
                $endePrinc = false;
                foreach($enderecos as $endereco) {
                    self::insertEndereco($endereco, $dadosAceite['CDCLIENTE'], $dadosAceite['NRORG']);
                    
                    //Endereço de Cobrança
                    if($endereco['IDTPENDEPROS'] == 'C') {
                        $auxEnde = true;
                    }
                    //Endereço Principal
                    if($endereco['IDTPENDEPROS'] == 'P') {
                        $endePrinc = $endereco;
                    }
                }

                //Se não existir o endereço de cobrança faz a copia do principal.
                if(($auxEnde === false) && ($endePrinc !== false)) {
                    $endePrinc['IDTPENDEPROS'] = 'C';
                    self::insertEndereco($endePrinc, $dadosAceite['CDCLIENTE'], $dadosAceite['NRORG']);
                }

                //Busca os interlocutores do Prospect e insere no Cliente
                $interlocutores = Inteprosp::getRepository()->consultaInterlocProsp($dadosAceite['CDPROSPECT']);

                foreach($interlocutores as $inter) {
                    self::insertInterlocutor($inter, $dadosAceite['CDCLIENTE'], $dadosAceite['NRORG']);
                }

                //Altera as informações dos contatos do prospect para o cliente
                $contatoProsp = Contato::findByCdprospectAndNrorg($dadosAceite['CDPROSPECT'], $dadosAceite['NRORG']);

                foreach($contatoProsp as $contato) {
                    self::atualizaContato($contato, $dadosAceite['CDCLIENTE']);

                    //Busca as Evolcont do prospect
                    $evolCont = Evolcont::findByNrcontatoAndCdprospect($contato->getNrcontato(), $dadosAceite['CDPROSPECT']);

                    foreach($evolCont as $evol) {
                        self::atualizaEvoltCont($evol, $dadosAceite['CDCLIENTE'], $evol->getCdintepros());
                    }
                }

                //Altera as informações da Ação do prospect para o cliente
                $acaoProsp = Acao::findByCdprospectAndIdtpmotivadoAndNrorg($dadosAceite['CDPROSPECT'], 'P', $dadosAceite['NRORG']);

                foreach($acaoProsp as $acao) {
                    self::atualizaAcao($acao, $dadosAceite['CDCLIENTE']);
                }

                //Altera as informações da Tarefa do prospect para o cliente
                $tarefaProsp = Tarefa::findByCdprospectAndIdtiptarefaAndNrorg($dadosAceite['CDPROSPECT'], 'P', $dadosAceite['NRORG']);

                foreach($tarefaProsp as $tarefa) {
                    self::atualizaTarefa($tarefa, $dadosAceite['CDCLIENTE']);
                }

                //Altera as informações da Observprosp do prospect para o cliente
                $obsProsp = Observprosp::findOneByCdprospectAndNrorg($dadosAceite['CDPROSPECT'], $dadosAceite['NRORG']);

                if(is_object($obsProsp)) {
                    if($obsProsp->getDsobservpros()) {
                        //Grava informações no Cliente
                        self::insertObservacao($obsProsp, $dadosAceite['CDCLIENTE'], $dadosAceite['NRORG'], $dadosAceite['CDOPERADOR']);
                        //Exclui as Informações do Prospect
                        self::deleteObservacao($obsProsp);
                    }
                }

                //Altera as informações da Movocorr do prospect para o cliente
                $movoCorr = Movocorr::findByCdprospectAndIdsitumovocorrAndNrorg($dadosAceite['CDPROSPECT'], 'P', $dadosAceite['NRORG']);

                foreach($movoCorr as $movo) {
                    self::atualizaMovocorr($movo, $dadosAceite['CDCLIENTE']);
                }

                //Altera as informações da Auditoria do prospect para o cliente
                $auditoria = Auditoria::findByCdprospectAndIdtpauditadoAndNrorg($dadosAceite['CDPROSPECT'], 'R', $dadosAceite['NRORG']);

                foreach($auditoria as $audit) {
                    self::atualizaAuditoria($audit, $dadosAceite['CDCLIENTE']);
                }

                //Altera as informações da Prospostafas do prospect para o cliente
                $propostaFas = Propostafas::findByCdprospectAndidclienprospAndNrorg($dadosAceite['CDPROSPECT'], 'P', $dadosAceite['NRORG']);

                foreach($propostaFas as $proposta) {
                    self::atualizaProposta($proposta, $dadosAceite['CDCLIENTE']);
                }
                
                //Altera as informações da Maladireta do prospect para o cliente
                $malaDireta = Maladireta::findByCdprospectAndNrorg($dadosAceite['CDPROSPECT'], $dadosAceite['NRORG']);
                
                foreach($malaDireta as $mala) {
                    self::atualizaMalaDireta($mala, $dadosAceite['CDCLIENTE']);
                }

                //Insere os registro na Parcliesfas para o Cliente
                for($i = 1; $i <= 6; $i++) {
                    if($i == 1) { 
                        $dsFaturClie = 'Prestação de serviços de processamento de dados.';
                        $dsBoletClie = 'Prestação de serviços de processamento de dados.';
                        self::insertParClieFas($dadosAceite['CDCLIENTE'], self::CUSTOMIZACAO, $dsFaturClie, $dsBoletClie, $dadosAceite['NRORG']);
                    } elseif($i == 2) {
                        $dsFaturClie = 'Cessão de direito de uso do sistema.';
                        $dsBoletClie = 'Cessão de direito de uso do sistema.';
                        self::insertParClieFas($dadosAceite['CDCLIENTE'], self::LICENCAUSO, $dsFaturClie, $dsBoletClie, $dadosAceite['NRORG']);
                    } elseif($i == 3) {
                        $dsFaturClie = 'Manutenção no processamento de dados.';
                        $dsBoletClie = 'Manutenção ref a [MM/YYYY].';
                        self::insertParClieFas($dadosAceite['CDCLIENTE'], self::MENSALIDADE, $dsFaturClie, $dsBoletClie, $dadosAceite['NRORG']);
                    } elseif($i == 5) {
                        $dsFaturClie = 'Suporte no processamento de dados ref prop COMxxxxxx-x.';
                        $dsBoletClie = 'Prestação de serviços.';
                        self::insertParClieFas($dadosAceite['CDCLIENTE'], self::MAODEOBRA, $dsFaturClie, $dsBoletClie, $dadosAceite['NRORG']);
                    } elseif($i == 6) {
                        $dsFaturClie = 'Prestação de serviços.';
                        $dsBoletClie = 'Prestação de serviços.';
                        self::insertParClieFas($dadosAceite['CDCLIENTE'], self::SUPORTE, $dsFaturClie, $dsBoletClie, $dadosAceite['NRORG']);
                    }
                }
                
                //Inativa o prospect. Depois caso não for possível deletar os seus registros o mesmo não poderá ser utilizado.
                self::inativaProspect($dadosAceite['CDPROSPECT'], $dadosAceite['NRORG']);
                
                //Reabilita as triggers
                self::enableTriggers($arrayTriggers);
            }
            
            $entityManager->flush();
        } catch(\Exception $e){
            self::enableTriggers($arrayTriggers);
            throw $e;
        }
    }
    
    public static function insertCliente($dadosAceite, $dadosProsp)
    {
        $cliente = new Cliente();
        
        $cliente->setNrorg($dadosAceite['NRORG']);
        $cliente->setCdcliente($dadosAceite['CDCLIENTE']);
        $cliente->setIdtpijurclie($dadosAceite['TPINCRICAO']);
        $cliente->setNrinsjurclie($dadosAceite['NUMJUR']);
        $cliente->setNmrazsocclie($dadosAceite['RAZAOSOCIAL']);
        $cliente->setNmfantclie($dadosAceite['NMFANTASIA']);
        $cliente->setNmcomprzscli($dadosAceite['COMPLEMENTO']);
        $cliente->setDtcadaclie($dadosAceite['DTATUAL']);
        $cliente->setNrmesreajclie($dadosAceite['MESREAJUSTE']);
        $cliente->setNrinsestclie($dadosProsp['NRINSESTPROS']);
        $cliente->setVrfatuclie($dadosProsp['VRFATUPROS']);
        $cliente->setNrfuncclie($dadosProsp['NRFUNCPROS']);
        $cliente->setNrunopclie($dadosProsp['NRUNOPPROS']);
        $cliente->setCdmododivulg($dadosProsp['CDMODODIVULG']);
        $cliente->setCdativcli($dadosProsp['CDATIVCLI']);
        $cliente->setCdsegmer($dadosProsp['CDSEGMER']);
        $cliente->setDshomepacli($dadosProsp['DSHOPAPROS']);
        $cliente->setNrparcnegocio($dadosProsp['NRPARCNEGOCIO']);
        $cliente->setDtinclusao(DateUtil::getDataAtual());
        $cliente->setIdutliceuso('S');
        $cliente->setIdlibgerper('S');
        $cliente->setNrdiavalpers(60);
        
        if(isset($dadosProsp['DTCADAPROS'])) {
            $cliente->setDtcadaclpros(DateUtil::getDataDeString($dadosProsp['DTCADAPROS'], DateUtil::FORMATO_BRASILEIRO_DATAHORA));
        }

        $cliente->persist();
        
        Registry::getEntityManager()->flush();
    }

    public static function insertParceria($nrParceria, $nrParcnegocio, $nrOrg)
    {
        $parceria = new Parceria();
        
        $parceria->setNrorg($nrOrg);
        $parceria->setNrparceria($nrParceria);
        $parceria->setNrparcnegocio($nrParcnegocio);
        $parceria->setDtinclusao(DateUtil::getDataAtual());
        $parceria->setCdtipoparceiro('CLIENTE');
        $parceria->setIdativo('S');
        $parceria->setNrorginclusao($nrOrg);
        $parceria->setNrorgultatu($nrOrg);
        $parceria->setCdoperinclusao(Ambiente::getCdoperador());
        $parceria->setCdoperultatu(Ambiente::getCdoperador());

        $parceria->persist();
    }

    public static function atualizaParcNegocio($nrParcnegocio, $nrOrg)
    {
        $parcNegocio = Parcnegocio::findOneByNrparcnegocioAndNrorg($nrParcnegocio, $nrOrg);

        if(is_object($parcNegocio)) {
            $parcNegocio->setCdtipoparcprincipal('CLIENTE');
            $parcNegocio->persist();
        }
    }

    public static function insertEndereco($endereco, $cdCliente, $nrOrg)
    {
        $endeClie = new Endeclie();

        $endeClie->setNrorg($nrOrg);
        $endeClie->setCdcliente($cdCliente);
        $endeClie->setDtinclusao(DateUtil::getDataAtual());
        $endeClie->setIdtpendeclie($endereco['IDTPENDEPROS']);
        $endeClie->setCdpais($endereco['CDPAIS']);
        $endeClie->setSgestado($endereco['SGESTADO']);
        $endeClie->setCdmunicipio($endereco['CDMUNICIPIO']);
        $endeClie->setDsendeclie($endereco['DSENDEPROS']);
        $endeClie->setNmbairclie($endereco['NMBAIRPROS']);
        $endeClie->setNrcepclie($endereco['NRCEPPROS']);
        $endeClie->setNrteleclie($endereco['NRTELEPROS']);
        $endeClie->setNrramalclie($endereco['NRRAMALPROS']);
        $endeClie->setNrtelexclie($endereco['NRTELEXPROS']);
        $endeClie->setNrfaxclie($endereco['NRFAXPROS']);
        $endeClie->setNmcontclie($endereco['NMCONTPROS']);
        $endeClie->setDsemailclie($endereco['DSEMAILPROS']);
        $endeClie->setNrteleclie1($endereco['NRTELEPROS1']);
        $endeClie->setNrramalclie1($endereco['NRRAMALPROS1']);
        $endeClie->setNrtelresicli($endereco['NRTELRESIPRO']);
        $endeClie->setNrcelularcli($endereco['NRCELULARPRO']);
        $endeClie->setNrenderecoparc($endereco['NRENDERECOPARC']);
        $endeClie->setNrorginclusao($nrOrg);
        $endeClie->setNrorgultatu($nrOrg);
        $endeClie->setCdoperinclusao(Ambiente::getCdoperador());
        $endeClie->setCdoperultatu(Ambiente::getCdoperador());

        $endeClie->persist();
    }

    public static function insertInterlocutor($interlocutor, $cdCliente, $nrOrg)
    {
        $inteClie = new Inteclie();

        $inteClie->setNrorg($nrOrg);
        $inteClie->setCdcliente($cdCliente);
        $inteClie->setDtinclusao(DateUtil::getDataAtual());
        $inteClie->setCdinteclie($interlocutor['CDINTEPROS']);
        $inteClie->setNminteclie($interlocutor['NMINTEPROS']);
        $inteClie->setDscarginclie($interlocutor['DSCARGINPROS']);
        $inteClie->setIdtpinteclie($interlocutor['IDTPINTEPROS']);
        $inteClie->setIdinterrecpres($interlocutor['IDINPROSRECPRES']);
        $inteClie->setIdenvemailintfa('N');
        $inteClie->setCdpais($interlocutor['CDPAIS']);
        $inteClie->setSgestado($interlocutor['SGESTADO']);
        $inteClie->setCdmunicipio($interlocutor['CDMUNICIPIO']);
        $inteClie->setNrtel1inclie($interlocutor['NRTEL1INPROS']);
        $inteClie->setNrram1inclie($interlocutor['NRRAM1INPROS']);
        $inteClie->setNrtel2inclie($interlocutor['NRTEL2INPROS']);
        $inteClie->setNrram2inclie($interlocutor['NRRAM2INPROS']);
        $inteClie->setNrfaxinclie($interlocutor['NRFAXINPROS']);
        $inteClie->setIdendeinclie($interlocutor['IDENDEINPROS']);
        $inteClie->setDsendeinclie($interlocutor['DSENDEINPROS']);
        $inteClie->setNmbairinclie($interlocutor['NMBAIRINPROS']);
        $inteClie->setNrcepinclie($interlocutor['NRCEPINPROS']);
        $inteClie->setDsemailiclie($interlocutor['DSEMAILIPROS']);
        $inteClie->setIdstinteclie($interlocutor['IDSTINTEPROS']);
        $inteClie->setNrcelulincli($interlocutor['NRCELULINPRO']);
        $inteClie->setNrtelreincli($interlocutor['NRTELREINPRO']);
        $inteClie->setCdcargointerloc($interlocutor['CDCARGOINTERLOC']);
        $inteClie->setNrrelacionaparc($interlocutor['NRRELACIONAPARC']);
        $inteClie->setNrorginclusao($nrOrg);
        $inteClie->setNrorgultatu($nrOrg);
        $inteClie->setCdoperinclusao(Ambiente::getCdoperador());
        $inteClie->setCdoperultatu(Ambiente::getCdoperador());
        
        if(isset($interlocutor['DTNASCINPROS'])) {
            if(strlen($interlocutor['DTNASCINPROS']) > 10) {
                $inteClie->setDtnascinclie(DateUtil::getDataDeString($interlocutor['DTNASCINPROS'], DateUtil::FORMATO_BRASILEIRO_DATAHORA));
            } else {
                $inteClie->setDtnascinclie(DateUtil::getDataDeString($interlocutor['DTNASCINPROS'], DateUtil::FORMATO_BRASILEIRO));
            }        
        }

        $inteClie->persist();

        Registry::getEntityManager()->flush();
    }

    public static function atualizaContato(Contato $contato, $cdCLiente)
    {
        $contato->setIdtpcontato('C');
        $contato->setCdprospect(null);
        $contato->setCdcliente($cdCLiente);

        $contato->persist();
    }

    public static function atualizaEvoltCont(Evolcont $evolCont, $cdCLiente, $cdInteClie)
    {
        $evolCont->setIdtpevolcont('C');
        $evolCont->setCdprospect(null);
        $evolCont->setCdcliente($cdCLiente);
        $evolCont->setCdintepros(null);
        $evolCont->setCdinteclie($cdInteClie);

        $evolCont->persist();
    }

    public static function atualizaAcao(Acao $acao, $cdCLiente)
    {
        $acao->setIdtpmotivado('C');
        $acao->setCdprospect(null);
        $acao->setCdcliente($cdCLiente);

        $acao->persist();
    }

    public static function atualizaTarefa(Tarefa $tarefa, $cdCLiente)
    {
        $tarefa->setIdtiptarefa('C');
        $tarefa->setCdprospect(null);
        $tarefa->setCdcliente($cdCLiente);

        $tarefa->persist();
    }

    public static function insertObservacao(Observprosp $observ, $cdCliente, $nrOrg, $cdOperador)
    {
        $observClie = new Observclie();

        $observClie->setNrorg($nrOrg);
        $observClie->setCdcliente($cdCliente);
        $observClie->setCdoperador($cdOperador);
        $observClie->setDtinclusao(DateUtil::getDataAtual());
        $observClie->setDthrobsclie($observ->getDthrobsprosp());
        $observClie->setDthrobsclie($observ->getDsobservpros());
        $observClie->setIdativo('S');
        $observClie->setNrorginclusao($nrOrg);
        $observClie->setNrorgultatu($nrOrg);
        $observClie->setCdoperinclusao(Ambiente::getCdoperador());
        $observClie->setCdoperultatu(Ambiente::getCdoperador());

        $observClie->persist();
    }

    public static function deleteObservacao(Observprosp $observ)
    {
        $observ->delete();
    }

    public static function atualizaMovocorr(Movocorr $movoCorr, $cdCLiente)
    {
        $movoCorr->setIdsitumovocorr('C');
        $movoCorr->setCdprospect(null);
        $movoCorr->setCdcliente($cdCLiente);

        $movoCorr->persist();
    }

    public static function atualizaAuditoria(Auditoria $auditoria, $cdCliente)
    {
        $auditoria->setIdtpauditado('C');
        $auditoria->setCdprospect(null);
        $auditoria->setCdcliente($cdCliente);

        $auditoria->persist();
    }

    public static function atualizaMalaDireta(Maladireta $malaDireta, $cdCliente)
    {
        $malaDireta->setCdcliente($cdCliente);
        $malaDireta->setCdprospect(null);
        $malaDireta->setCdinteclie($malaDireta->getCdintepros());
        $malaDireta->setCdintepros(null);

        $malaDireta->persist();
    }

    public static function atualizaProposta(Propostafas $proposta, $cdCliente)
    {
        $proposta->setIdclienprosp('C');
        $proposta->setCdcliente($cdCliente);
        $proposta->setCdprospect(null);
        $proposta->setCdinteclie($proposta->getCdintepros());
        $proposta->setCdintepros(null);

        $proposta->persist();
    }
    
    public static function insertParClieFas($cdCliente, $idTpFatuClie, $dsFaturClie, $dsBoletClie, $nrOrg)
    {
        $parcClieFas = new Parcliefas();
        
        $parcClieFas->setCdcliente($cdCliente);
        $parcClieFas->setNrorg($nrOrg);
        $parcClieFas->setIdtpfatuclie($idTpFatuClie);
        $parcClieFas->setDsfaturclie($dsFaturClie);
        $parcClieFas->setDsboletclie($dsBoletClie);
        $parcClieFas->setDtinclusao(DateUtil::getDataAtual());
        $parcClieFas->setCdempresa('01');
        $parcClieFas->setIdfaturapfili('N');
        $parcClieFas->setIdfatmesatuclie('N');
        $parcClieFas->setIdgeranfunifica('N');
        $parcClieFas->setVrpercajusteinv(0);
        $parcClieFas->setNrorginclusao($nrOrg);
        $parcClieFas->setNrorgultatu($nrOrg);
        $parcClieFas->setCdoperinclusao(Ambiente::getCdoperador());
        $parcClieFas->setCdoperultatu(Ambiente::getCdoperador());

        $parcClieFas->persist();
    }

    public static function deleteRegistrosProspect($cdProspect, $nrOrg)
    {
        $entityManager = Registry::getEntityManager();
        $db = $entityManager->getConnection();
        $db->beginTransaction();

        try {
            $estInteresse = Estinteresse::findByCdprospectAndNrorg($cdProspect, $nrOrg);
            foreach ($estInteresse as $interesse) {
                $interesse->delete();
            }

            $escoPros = Escopros::findByCdprospectAndNrorg($cdProspect, $nrOrg);
            foreach ($escoPros as $esco) {
                $esco->delete();
            }
            
            $prospFilial = Prospfilial::findByCdprospectAndNrorg($cdProspect, $nrOrg);
            foreach ($prospFilial as $prosp) {
                $prosp->delete();
            }
            
            $histQualPros = Histqualpros::findByCdprospectAndNrorg($cdProspect, $nrOrg);
            foreach ($histQualPros as $histQual) {
                $histQual->delete();
            }
            
            $qualifProsp = Qualifprosp::findByCdprospectAndNrorg($cdProspect, $nrOrg);
            foreach ($qualifProsp as $qualif) {
                $qualif->delete();
            }
            
            $cursoProspect = Cursoprospect::findByCdprospectAndNrorg($cdProspect, $nrOrg);
            foreach ($cursoProspect as $curso) {
                $curso->delete();
            }
            
            $endeProspect = Endeprospect::findByCdprospectAndNrorg($cdProspect, $nrOrg);
            foreach ($endeProspect as $ende) {
                $ende->delete();
            }
            
            $inteProsp = Inteprosp::findByCdprospectAndNrorg($cdProspect, $nrOrg);
            foreach ($inteProsp as $inte) {
                $inte->delete();
            }
            
            $prospect = Prospect::findOneByCdprospectAndNrorg($cdProspect, $nrOrg);
            if(is_object($prospect)) {
                $prospect->delete();
            }
            
            $entityManager->flush();
            $db->commit();
        } catch (\Exception $e) {
            $db->rollback();          
        }
    }
    
    public static function inativaProspect($cdProspect, $nrOrg)
    {
        $entityManager = \Setforms2\Shared\Registry::getEntityManager();
        
        $prospect = Prospect::findOneByCdprospectAndNrorg($cdProspect, $nrOrg);
        $prospect->setIdsitupros('I');
        
        $prospect->persist();
        
        $entityManager->flush();
    }

    public static function disableTriggers()
    {
        $arrayTriggers = array('STS_PARCNEGO' => 'NULL',
                               'STS_ENDEPARC' => 'NULL',
                               'STS_RELAPARC' => 'NULL');

        $trigParcNego = Propostafas::getRepository()->verificaTriggerAceite('GERA_PARCNEGOCIO_CLIENTE');
        if($trigParcNego[0]['COUNTTRIGGER'] > 0) {
            Propostafas::getRepository()->disableEnableTriggerAceite('GERA_PARCNEGOCIO_CLIENTE', 'DISABLE');
            $arrayTriggers['STS_PARCNEGO'] = $trigParcNego[0]['STATUS'];
        }

        $trigEndeParc = Propostafas::getRepository()->verificaTriggerAceite('GERA_ENDERECOPARC_ENDCLIE');
        if($trigEndeParc[0]['COUNTTRIGGER'] > 0) {
            Propostafas::getRepository()->disableEnableTriggerAceite('GERA_ENDERECOPARC_ENDCLIE', 'DISABLE');
            $arrayTriggers['STS_ENDEPARC'] = $trigEndeParc[0]['STATUS'];
        }

        $trigRelaParc = Propostafas::getRepository()->verificaTriggerAceite('GERA_RELAC_PARCNEG_INTECLIE');
        if($trigRelaParc[0]['COUNTTRIGGER'] > 0) {
            Propostafas::getRepository()->disableEnableTriggerAceite('GERA_RELAC_PARCNEG_INTECLIE', 'DISABLE');
            $arrayTriggers['STS_ENDEPARC'] = $trigRelaParc[0]['STATUS'];
        }

        return $arrayTriggers;
    }

    public static function enableTriggers($arrayTriggers)
    {
        if($arrayTriggers['STS_PARCNEGO'] == 'ENABLED') {
            Propostafas::getRepository()->disableEnableTriggerAceite('GERA_PARCNEGOCIO_CLIENTE', 'ENABLE');
        }

        if($arrayTriggers['STS_ENDEPARC'] == 'ENABLED') {
            Propostafas::getRepository()->disableEnableTriggerAceite('GERA_ENDERECOPARC_ENDCLIE', 'ENABLE');
        }

        if($arrayTriggers['STS_ENDEPARC'] == 'ENABLED') {
            Propostafas::getRepository()->disableEnableTriggerAceite('GERA_RELAC_PARCNEG_INTECLIE', 'ENABLE');
        }
    }
}