/*
NOME: 0008_CARSTPO_USR_EXPORTACUSTOLISTAPRECO.SQL
DESCRIO: Procedimento para exportao do custo de lista de preos dos produtos.
CRIAO: 20/03/2012 - Marcelo Alexsandro Souza Silva
*/

CREATE OR REPLACE
PROCEDURE USR_EXPORTACUSTOLISTAPRECO
  (P_DTINICIAL    IN DATE,
   P_DTFINAL      IN DATE) IS

   V_DTGRV        DATE;
   V_HRGRV        VARCHAR2(4);
   V_CDPERIENTR   PERIENTR.CDPERIENTR%TYPE;
   V_NMPERIENTR   PERIENTR.NMPERIENTR%TYPE;
   V_IDTIPODIA    PERIENTR.IDTIPODIA%TYPE;
   V_QTMINFORNREG MINFORNREG.QTMINFORNREG%TYPE;
   V_VRMINFORNREG MINFORNREG.VRMINFORNREG%TYPE;
   V_SGUNIDADE    UNIDMEDIDA.SGUNIDADE%TYPE;
   V_CDFILIAL     FILIAL.CDFILIAL%TYPE;

   V_CDARVPRODESTO PRODUTO.CDARVPROD%TYPE;
   V_CDARVPRODCMP  PRODUTO.CDARVPROD%TYPE;

   V_NMPRODCOMPRA  PRODUTO.NMPRODUTO%TYPE;
   V_NMPRODESTOQUE PRODUTO.NMPRODUTO%TYPE;

   V_NMMARCA       MARCA.NMMARCA%TYPE;

   V_ERROR         VARCHAR2(4000);

   V_CDPERIPROD    VARCHAR2(2);

   /* - Declarao de cursores ---------------------------------------------- */
   CURSOR C_FILIAIS IS
      SELECT CDFILIAL
        FROM FILGRUPFILI
       WHERE FILGRUPFILI.CDGRUPFILI = '9999999999';
   V_DIAS         VARCHAR2(300);
   V_RETURN       VARCHAR2(1);
BEGIN
   V_RETURN := USR_FUNC_BLOQUEIO('USR_LISTAPRECO', 'B');
   IF V_RETURN = 'S' THEN
      V_DTGRV := NULL;
      V_HRGRV := NULL;

      /* Retorna data e hora de exportao */
      BEGIN
        SELECT TO_DATE(SYSDATE), TO_CHAR(SYSDATE,'HH24MI')
          INTO V_DTGRV, V_HRGRV
          FROM DUAL;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN
           V_DTGRV := NULL;
           V_HRGRV := NULL;
      END;

      OPEN C_FILIAIS;
      LOOP
        FETCH C_FILIAIS INTO V_CDFILIAL;
        EXIT WHEN C_FILIAIS%NOTFOUND;

        DELETE FROM USR_LISTAPRECO
         WHERE DTREFERENCIA BETWEEN P_DTINICIAL AND P_DTFINAL
           AND CDFILIAL = V_CDFILIAL;
        FOR C_CUSTOSUP IN
           (SELECT
               CUSTOSUP.CDFILIAL,
               CUSTOSUP.CDPRODUTO CDPRODESTO,
               CUSTOSUP.DTCUSTOSUP,
               CUSTOSUP.DTFINCUSTSUP,
               CUSTOSUP.VRCUSPRLISTP,
               NVL(CUSTOSUP.CDFORNECACOR, CUSTOSUP.CDFORNECLIST) CDFORNECED,
               NVL(CUSTOSUP.CDPRODACOR, CUSTOSUP.CDPRODLIST) CDPRODCOMPRA,
               NVL(CUSTOSUP.CDREGIAOACOR, CUSTOSUP.CDREGIAOLIST) CDREGIAO,
               NVL(CUSTOSUP.CDMARCAACOR, CUSTOSUP.CDMARCALIST) CDMARCA,
               NVL(PRODUTO.VRFATOCONV, 1) VRFATOCONV
            FROM CUSTOSUP, PRODUTO
           WHERE CUSTOSUP.CDFILIAL = V_CDFILIAL
             AND CUSTOSUP.DTCUSTOSUP BETWEEN P_DTINICIAL AND P_DTFINAL
             AND PRODUTO.CDPRODUTO = NVL(CUSTOSUP.CDPRODACOR, CUSTOSUP.CDPRODLIST))
        LOOP
           SELECT NVL(MAX(QTMINFORNREG), MAX(QTMINAUTFOT)), NVL(MAX(VRMINFORNREG), MAX(VRMINAUTFOR)), MAX(SGUNIDADE)
             INTO V_QTMINFORNREG, V_VRMINFORNREG, V_SGUNIDADE
             FROM FORNECEDOR, MINFORNREG
            WHERE FORNECEDOR.CDFORNECED = C_CUSTOSUP.CDFORNECED
              AND FORNECEDOR.CDFORNECED = MINFORNREG.CDFORNECED(+)
              AND C_CUSTOSUP.CDREGIAO   = MINFORNREG.CDREGIAO(+);

           V_CDPERIENTR := NULL;
           V_NMPERIENTR := NULL;
           SELECT MAX(P.CDPERIENTR), MAX(P.NMPERIENTR), MAX(IDTIPODIA)
             INTO V_CDPERIENTR, V_NMPERIENTR, V_IDTIPODIA
             FROM REFORFIL, PERIENTR P
            WHERE REFORFIL.CDFORNECED = C_CUSTOSUP.CDFORNECED
              AND REFORFIL.CDFILIAL   = V_CDFILIAL
              AND REFORFIL.CDPERIENTR = P.CDPERIENTR;

           SELECT MAX(PERFILPROD.CDPERIENTR)
              INTO V_CDPERIPROD
            FROM PRODUTO, PRODUTO PRODPERIENTR, PERFILPROD, PERIENTR
            WHERE PRODUTO.CDPRODESTO     = C_CUSTOSUP.CDPRODESTO
              AND PERFILPROD.CDPRODUTO   = PRODPERIENTR.CDPRODUTO
              AND PERFILPROD.CDFILIAL    = V_CDFILIAL
              AND PERFILPROD.CDPERIENTR  = PERIENTR.CDPERIENTR
              AND PRODPERIENTR.CDARVPROD = (SELECT
                                               MAX(B.CDARVPROD)
                                            FROM
                                               PERFILPROD A,
                                               PRODUTO B
                                            WHERE A.CDPRODUTO = B.CDPRODUTO
                                              AND A.CDFILIAL  = V_CDFILIAL
                                              AND INSTR(PRODUTO.CDARVPROD, B.CDARVPROD) = 1);
           V_DIAS := NULL;
           IF V_CDPERIENTR IS NOT NULL THEN
              FOR C_DIAS IN
                 (SELECT DIENTREGA
                    FROM DIASENTR
                   WHERE CDPERIENTR = V_CDPERIENTR)
              LOOP
                 V_DIAS := V_DIAS||', '||C_DIAS.DIENTREGA;
              END LOOP;

              IF V_IDTIPODIA = 'S' THEN
                 V_DIAS := 'SEMANALMENTE - '||V_DIAS;
              ELSE
                 IF V_IDTIPODIA = 'M' THEN
                    V_DIAS := 'MENSUAL - '||V_DIAS;
                 ELSE
                    V_DIAS := 'SUPLICANTE SEMANALMENTE - '||V_DIAS;
                 END IF;
              END IF;
           END IF;

           SELECT MAX(CDARVPROD), MAX(NMPRODUTO)
             INTO V_CDARVPRODESTO, V_NMPRODESTOQUE
             FROM PRODUTO
            WHERE PRODUTO.CDPRODUTO = C_CUSTOSUP.CDPRODESTO;

           SELECT MAX(CDARVPROD), MAX(NMPRODUTO)
             INTO V_CDARVPRODCMP, V_NMPRODCOMPRA
             FROM PRODUTO
            WHERE PRODUTO.CDPRODUTO = C_CUSTOSUP.CDPRODCOMPRA;

           SELECT MAX(NMMARCA)
             INTO V_NMMARCA
             FROM MARCA
            WHERE MARCA.CDMARCA = C_CUSTOSUP.CDMARCA;

           INSERT INTO USR_LISTAPRECO (CDFILIAL, CDPRODESTO, DTREFERENCIA,
                                       VRPRECUNIESTQ, VRPRECUNICMP, CDFORNECED,
                                       CDPRODUTO, VRMINIMOFORN, QTMINIMOFORN,
                                       SGUNIDADE, CDPERIENTR, NMPERIENTR,
                                       IDORIGREGISTRO, DTGRAVACAO, HRGRAVACAO, DTIMPORTACAO, HRIMPORTACAO,
                                       NMPRODCOMPRA, NMPRODESTOQUE, DIAS, DTFINAL, CDMARCA, NMMARCA, CDPERIPROD)
           VALUES (V_CDFILIAL, V_CDARVPRODESTO, C_CUSTOSUP.DTCUSTOSUP,
                   C_CUSTOSUP.VRCUSPRLISTP, C_CUSTOSUP.VRCUSPRLISTP * C_CUSTOSUP.VRFATOCONV,
                   C_CUSTOSUP.CDFORNECED, V_CDARVPRODCMP, V_VRMINFORNREG, V_QTMINFORNREG,
                   V_SGUNIDADE, V_CDPERIENTR, V_NMPERIENTR,
                   'T', NULL, NULL, NULL, NULL,
                   V_NMPRODCOMPRA, V_NMPRODESTOQUE, V_DIAS, C_CUSTOSUP.DTFINCUSTSUP, C_CUSTOSUP.CDMARCA, V_NMMARCA, V_CDPERIPROD);
        END LOOP;
        UPDATE USR_LISTAPRECO
           SET DTGRAVACAO = V_DTGRV, HRGRAVACAO = V_HRGRV
         WHERE DTREFERENCIA BETWEEN P_DTINICIAL AND P_DTFINAL
           AND CDFILIAL = V_CDFILIAL;
        COMMIT;
      END LOOP;
      CLOSE C_FILIAIS;
      V_RETURN := USR_FUNC_BLOQUEIO('USR_LISTAPRECO', 'D');
   END IF;
EXCEPTION
  WHEN OTHERS THEN BEGIN
     IF V_RETURN = 'S' THEN
        V_ERROR:= SQLERRM(SQLCODE);
        V_RETURN := USR_FUNC_BLOQUEIO('USR_LISTAPRECO', 'D', V_ERROR);
     END IF;
  END;
END;
/

-- VERSAO --
BEGIN ATUVEROBJ('USR_EXPORTACUSTOLISTAPRECO','5.09.xxx'); END;
/
